import 'dart:core';
import 'package:flutter/material.dart';
import 'package:intl/intl.dart';

extension NumberParse on String {
  int toInt() {
    return int.parse(this);
  }

  String removeCharts() {
    return replaceAll(RegExp('[^A-Za-z0-9]'), '');
  }

  String formatPhone() =>
       replaceAllMapped(RegExp(r'(\d{2})(\d{2})(\d{2})(\d+)'), (Match m) => "${m[1]} ${m[2]} ${m[3]} ${m[4]}");
}

extension NumberFormateInt on int? {
  String formatPattern() =>
      NumberFormat.decimalPattern("es_MX").format(this ?? 0);
}


extension NumberFormateDouble on double? {
  String formatPattern() =>
      NumberFormat.decimalPattern("es_MX").format(this ?? 0);
}

extension NumberFormateNum on num? {
  String formatPattern() =>
      NumberFormat.decimalPattern("es_MX").format(this ?? 0);
}

extension DateFormating on DateTime {
  String formatDate() {
    return DateFormat("yyyy-MM-dd").format(this);
  }

  String formatHour() {
    return DateFormat("hh:mm aa").format(this);
  }

  String formatDateHour() {
    return DateFormat("yyyy-MM-dd hh:mm aa").format(this);
  }

  String formatDateNameMonth() {
    return DateFormat('dd MMMM yyyy', 'ES').format(this);
  }
}

extension DurationFormat on Duration {
  String prettyDuration() {
    var components = <String>[];

    var days = inDays;
    if (days != 0) {
      components.add('$days ${days == 1 ? "dia" : "dias"} con ');
    }
    var hours = inHours % 24;
    if (hours != 0) {
      components.add('$hours ${days == 1 ? "hora" : "horas"} y ');
    }
    var minutes = inMinutes % 60;
    if (minutes != 0) {
      components.add('$minutes ${minutes == 1 ? "minuto" : "minutos"}');
    }

/*    var seconds = this.inSeconds % 60;
    var centiseconds =
        (this.inMilliseconds % 1000) ~/ 10;
    if (components.isEmpty || seconds != 0 || centiseconds != 0) {
      components.add('$seconds');
      if (centiseconds != 0) {
        components.add('.');
        components.add(centiseconds.toString().padLeft(2, '0'));
      }
      components.add('s');
    }*/
    return components.join();
  }
}

//region extension widgets

extension VisibilityWait on Visibility {
  Widget wait({required Future<bool> visible, required Widget child, Widget? replacement}) {
    return FutureBuilder<bool>(
        future: visible,
        builder: (BuildContext context, AsyncSnapshot<bool> snapshot) {
          if (snapshot.data!) {
            return child;
          } else {
            return replacement ?? const Text("");
          }
        });
  }
}
//endregion
