import 'package:flutter/material.dart';
import 'package:get/get.dart';

class MsgUtils {
  static success(
          {String message = "Proceso Realizado Correctamente",
          title = 'Operacion correcta',
          Color? backgroundColor}) =>
      _showMessage(message, title, backgroundColor);

  static error(
          {String message = "¡Ah Ocurrido un error!",
          String title = 'Error',
          Color? backgroundColor}) =>
      _showMessage(message, title, backgroundColor);

  static _showMessage(String message, String title, Color? backgroundColor) {
    Get.defaultDialog(
        title: title,
        middleText: message,
        backgroundColor: backgroundColor,
        actions: [
          ElevatedButton(
              onPressed: () => Get.back(),
              style: ButtonStyle(
                  backgroundColor:
                      MaterialStateProperty.all<Color>(Colors.black)),
              child:
                  const Text("Aceptar", style: TextStyle(color: Colors.white)))
        ]);
  }

  static confirm(String message, Function onConfirm, Function onCancel,
      {String title = 'Confirmación',
      String acceptText = 'Aceptar',
      String cancelText = 'Cancelar'}) async {
    final result = await showDialog(
        context: Get.context!,
        barrierDismissible: false,
        builder: (builder) {
          return AlertDialog(
              title: Text(title,
                  style: Theme.of(Get.context!).textTheme.bodyLarge),
              content: Text(message,
                  style: Theme.of(Get.context!).textTheme.bodyMedium,
                  textAlign: TextAlign.center),
              actions: <Widget>[
                _options(Get.context!, 'Cancelar', false),
                _options(Get.context!, 'Aceptar', true,
                    color: Theme.of(Get.context!).colorScheme.background)
              ]);
        });

    if (result) {
      onConfirm();
    } else {
      onCancel();
    }
  }

  static Future<bool> exit(GestureTapCallback onConfirm,
      {String title = "Advertencía", String message = '¿Deseas Salir?'}) async {
    final result = await Get.dialog(AlertDialog(
        backgroundColor: Colors.white,
        title: Text(
          title,
          style: const TextStyle(fontSize: 17, fontWeight: FontWeight.bold),
        ),
        content: Text(
          message,
          textAlign: TextAlign.start,
        ),
        actions: <Widget>[
          _options(Get.context!, 'Cancelar', false,
              color: Theme.of(Get.context!).colorScheme.primary),
          _options(Get.context!, 'Aceptar', true)
        ]));
    if (result) onConfirm();
    return result;
  }

  static TextButton _options(BuildContext context, String text, bool isCancel,
      {Color color = Colors.grey}) {
    return TextButton(
        style: TextButton.styleFrom(
            foregroundColor: Colors.white,
            backgroundColor: color,
            textStyle: Theme.of(context).textTheme.bodyMedium),
        child: Text(text),
        onPressed: () => Navigator.of(context).pop(isCancel));
  }
}
