import 'package:flutter/material.dart';

class CustomButton extends StatelessWidget {
  const CustomButton(
      {Key? key,
      required this.text,
      required this.onPressed,
      this.enable = false,
      this.color = Colors.blue,
      this.textColor = Colors.black})
      : super(key: key);

  final GestureTapCallback onPressed;
  final String text;
  final bool enable;
  final Color color;
  final Color textColor;

  @override
  Widget build(BuildContext context) {
    return enable
        ? _disableButton(context)
        : ElevatedButton(
            onPressed: onPressed,
            style: ButtonStyle(
                backgroundColor:
                    MaterialStateProperty.all(defineColor(context)),
                shape: MaterialStateProperty.all<RoundedRectangleBorder>(
                    RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(5)))),
            child: Container(
                padding: const EdgeInsets.all(8),
                child: Text(text,
                    style: TextStyle(
                        color: textColor,
                        fontSize: 15,
                        fontWeight: FontWeight.bold))),
          );
  }

  _disableButton(BuildContext context) {
    return ElevatedButton(
        style: ElevatedButton.styleFrom(
            backgroundColor: Colors.grey[800], disabledBackgroundColor: Colors.grey),
        onPressed: null,
        child: Container(
            padding: const EdgeInsets.all(20),
            child: Text(text, style: const TextStyle(color: Colors.white))));
  }

  Color defineColor(BuildContext context) {
    if (color == Colors.blue) {
      return Colors.blue[700]!;
    } else {
      return color;
    }
  }
}