import 'package:eishon_widgets/src/utils/decoration.utils.dart';
import 'package:eishon_widgets/src/values/validation_messages.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:reactive_forms/reactive_forms.dart';

class CustomReactiveTextField extends StatelessWidget {
  final String controlName;
  late final String labelText;
  final TextInputType? keyboard;
  final int? maxLength;
  final int? minLength;
  final int? maxLines;
  final bool isPass;
  final IconData? iconSuffix;
  final void Function(FormControl<dynamic>)? onSubmitted;
  final TextEditingController textEditing = TextEditingController(text: "");
  final InputDecoration? decoration;
  final String? isNotMatch;
  final double? customPadding;
  final List<TextInputFormatter>? inputFormatters;

  CustomReactiveTextField(
    this.controlName, {
    super.key,
    this.labelText = "",
    this.maxLength,
    this.minLength,
    this.onSubmitted,
    this.iconSuffix,
    this.maxLines,
    this.isPass = false,
    this.decoration,
    this.isNotMatch,
    this.keyboard,
    this.customPadding = 10.0,
    TextEditingController? controller,
    this.inputFormatters,
    Function(dynamic value)? onChanged,
  }) {
    if (labelText.isEmpty) labelText = controlName;
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: EdgeInsets.all(customPadding!),
      child: ReactiveTextField(
        formControlName: controlName,
        controller: textEditing,
        autofocus: false,
        autocorrect: false,
        onSubmitted: onSubmitted,
        inputFormatters: inputFormatters,
        maxLines: maxLines ?? 1,
        maxLengthEnforcement: MaxLengthEnforcement.truncateAfterCompositionEnds,
        maxLength: maxLength,
        validationMessages: validationMessages(minLength, maxLength, isNotMatch),
        keyboardType: keyboard,
        style: Theme.of(context).textTheme.bodyMedium,
        decoration: decoration ?? DecorationUtils.outLine(context, labelText: labelText, suffixIcon: iconSuffix),
        obscureText: isPass,
        clipBehavior: Clip.none,
        scrollPhysics: const NeverScrollableScrollPhysics(),
        showCursor: true,
      ),
    );
  }
}
